@@ -2,7 +2,7 @@
 #'  \tabular{ll}{
 #'   **Package:** \tab khroma \cr
 #'   **Type:** \tab Package \cr
-#'   **Version:** \tab 1.10.0 \cr
+#'   **Version:** \tab 1.11.0 \cr
 #'   **License:** \tab GPL-3 \cr
 #'   **Zenodo:** \tab \doi{10.5281/zenodo.1472077} \cr
 #'  }
@@ -32,23 +32,7 @@
 #' @keywords internal
 "_PACKAGE"
 
-# @importFrom ggplot2 aes continuous_scale discrete_scale scale_color_manual
-# scale_fill_manual
-# @importFrom scales alpha gradient_n_pal rescale_mid
-# @importFrom spacesXYZ DeltaE
 #' @importFrom graphics hist image legend
 #' @importFrom grDevices col2rgb colorRamp colorRampPalette rgb
 #' @importFrom grid gpar grid.newpage grid.rect grid.text unit
 NULL
-
-`%||%` <- function(x, y) {
-  if (!is.null(x)) x else y
-}
-
-check_package <- function(x) {
-  if (!requireNamespace(x, quietly = TRUE)) {
-    msg <- "Package %s needed for this function to work. Please install it."
-    stop(sprintf(msg, x), call. = FALSE)
-  }
-  invisible(NULL)
-}
